@@ -37,7 +37,7 @@ class TimeoutPIDLockFile(PIDLockFile, object):
 
             """
         self.acquire_timeout = acquire_timeout
-        super(TimeoutPIDLockFile, self).__init__(path, *args, **kwargs)
+        super().__init__(path, *args, **kwargs)
 
     def acquire(self, timeout=None, *args, **kwargs):
         """ Acquire the lock.
@@ -54,10 +54,10 @@ class TimeoutPIDLockFile(PIDLockFile, object):
             """
         if timeout is None:
             timeout = self.acquire_timeout
-        super(TimeoutPIDLockFile, self).acquire(timeout, *args, **kwargs)
+        super().acquire(timeout, *args, **kwargs)
 
 
-# Copyright © 2008–2018 Ben Finney <ben+python@benfinney.id.au>
+# Copyright © 2008–2019 Ben Finney <ben+python@benfinney.id.au>
 #
 # This is free software: you may copy, modify, and/or distribute this work
 # under the terms of the Apache License, version 2.0 as published by the
